import { CallSession } from '../sip';
import { Client, UserCallRequest } from './client';
import { QueueParameters } from './queue';
import { MemberCommunication, Reporting, Task, TaskData } from './task';
export interface CallParameters {
    timeout?: number;
    video?: boolean;
    audio?: boolean;
    screen?: boolean;
    disableStun?: boolean;
    autoAnswer?: boolean;
    display?: string;
    variables?: Map<string, string>;
}
export declare enum CallReportingStatus {
    Abandoned = "abandoned",
    Cancel = "cancel",
    Success = "success"
}
export interface Categories {
    [key: string]: string;
}
export interface CallVariables {
    [key: string]: string;
}
export interface CallItem {
    id: string;
    app_id: string;
    state: string;
    timestamp: number;
    type: string;
    parent_id?: string;
    extension?: string;
    direction: string;
    destination: string;
    from: CallEndpoint;
    to?: CallEndpoint;
    variables: CallVariables;
    created_at: number;
    answered_at?: number;
    bridged_at?: number;
    hangup_at?: number;
    duration: number;
    hold_sec: number;
    wait_sec?: number;
    bill_sec?: number;
    queue?: object;
    joined_at?: number;
    leaving_at?: number;
    reporting_at?: number;
    queue_bridged_at?: number;
    queue_wait_sec?: number;
    queue_duration_sec?: number;
    reporting_sec?: number;
    display?: number;
    task?: TaskData;
}
export interface OutboundCallRequest {
    sdp?: string;
    destination?: string;
    stream?: MediaStream;
    params?: CallParameters;
}
export interface EavesdropRequest {
    id: string;
    control?: boolean;
    listenA?: boolean;
    listenB?: boolean;
    whisperA?: boolean;
    whisperB?: boolean;
    group?: string;
}
export declare enum CallActions {
    Ringing = "ringing",
    Active = "active",
    Bridge = "bridge",
    Hold = "hold",
    DTMF = "dtmf",
    Voice = "voice",
    Silence = "silence",
    Execute = "execute",
    Update = "update",
    Hangup = "hangup",
    Reporting = "reporting",
    PeerStream = "peerStream",
    LocalStream = "localStream",
    Destroy = "destroy"
}
export declare enum CallDirection {
    Inbound = "inbound",
    Outbound = "outbound"
}
export interface AnswerRequest {
    audio?: boolean;
    video?: boolean;
    screen?: boolean;
    disableStun?: boolean;
}
export interface CallEventData {
    id: string;
    app_id: string;
    cc_app_id: string;
    timestamp: number;
    event: string;
    data?: object;
}
export interface CallEventExecute extends CallEventData {
    application: string;
}
export interface CallEventDTMF extends CallEventData {
    digit: string;
}
export interface CallEndpoint {
    type: string;
    number?: string;
    id?: string;
    name?: string;
}
export interface CallBridged extends CallEventData {
    bridged_id: string;
    to?: CallEndpoint;
    queue?: QueueParameters;
    payload?: Map<string, string>;
}
export interface CallInfo extends CallEventData {
    sip_id: string;
    parent_id?: string;
    user_id?: string;
    direction: string;
    destination: string;
    queue?: QueueParameters;
    from: CallEndpoint;
    to?: CallEndpoint;
    payload: Map<string, string>;
    params?: CallParams;
}
export interface CallHangup extends CallEventData {
    cause: string;
    sip: number;
    reporting_at: number;
}
export interface CallParams {
    audio?: boolean;
    video?: boolean;
    screen?: boolean;
    autoAnswer?: boolean;
    disableStun?: boolean;
}
export interface MemberInfoRequest {
    fields?: string[];
}
export declare class Call {
    protected client: Client;
    data: any;
    id: string;
    appId: string;
    sipId: string | null;
    state: string;
    params: CallParams;
    direction: string;
    destination: string;
    from: CallEndpoint;
    to?: CallEndpoint;
    toNumber: string;
    toName: string;
    variables: Map<string, string>;
    postProcessData: object;
    peerStreams: MediaStream[];
    localStreams: MediaStream[];
    sip: CallSession | null;
    screen: string | null;
    createdAt: number;
    answeredAt: number;
    bridgedAt: number;
    hangupAt: number;
    reportingAt: number;
    hangupCause: string;
    hangupSipCode: number;
    parentId?: string;
    bridgedId: string;
    queue: QueueParameters | null;
    _muted: boolean;
    digits: string[];
    applications: string[];
    voice: boolean;
    task: Task | null;
    autoAnswered: boolean;
    constructor(client: Client, e: CallEventData);
    setState(s: CallEventData): void;
    setSip(sip: CallSession | null): void;
    get duration(): number;
    get allowDtmf(): boolean;
    get allowHangup(): boolean;
    get allowHold(): boolean;
    get allowAnswer(): boolean | QueueParameters | undefined;
    get allowUnHold(): boolean;
    get memberCommunication(): MemberCommunication | null;
    getMember(req: MemberInfoRequest): Promise<object>;
    get isMember(): boolean;
    setActive(e: CallEventData): void;
    setBridged(s: CallEventData): void;
    setHold(e: CallEventData): void;
    setInfo(s: CallInfo): void;
    setPeerStreams(streams: MediaStream[] | null): void;
    setLocalStreams(streams: MediaStream[] | null): void;
    setVoice(): void;
    setSilence(): void;
    setExecute(s: CallEventExecute): void;
    addDigit(s: CallEventDTMF): void;
    setHangup(s: CallEventData): void;
    get allowReporting(): boolean;
    get hasReporting(): boolean;
    get display(): string;
    get muted(): boolean;
    get isHold(): boolean;
    get allowInboundVideo(): boolean;
    get allowOutboundVideo(): boolean;
    get active(): boolean;
    get displayNumber(): string | undefined;
    get displayName(): string | undefined;
    get autoAnswer(): boolean;
    answer(req: AnswerRequest): Promise<boolean>;
    answerDelay(req: AnswerRequest, delay: number): void;
    hangup(cause?: string): Promise<object>;
    eavesdrop(req: EavesdropRequest): Promise<object>;
    toggleHold(): Promise<object>;
    hold(): Promise<object>;
    unHold(): Promise<object>;
    sendDTMF(dtmf: string): Promise<object>;
    blindTransfer(destination: string): Promise<object>;
    mute(mute?: boolean): Promise<object>;
    bridgeTo(call: Call): Promise<object>;
    reporting(reporting: Reporting): Promise<object>;
    renew(sec?: number): Promise<object>;
    callToUser(req: UserCallRequest): Promise<object>;
}
//# sourceMappingURL=call.d.ts.map