import { EventEmitter } from 'ee-ts';
import { SipPhone } from '../sip/webrtc';
import { Agent, AgentStatusEvent } from './agent';
import { AnswerRequest, Call, CallActions, CallItem, CallVariables, EavesdropRequest, OutboundCallRequest } from './call';
import { Conversation, ConversationItem } from './conversation';
import { QueueJoinMemberEvent } from './queue';
import { Reporting, Task, TaskData } from './task';
import { UserStatus } from './user';
export interface Config {
    endpoint: string;
    storageEndpoint?: string;
    token?: string;
    logLvl?: 'debug' | 'info' | 'warn' | 'error';
    registerWebDevice?: boolean;
    phone?: number;
    debug?: boolean;
}
export interface UserCallRequest {
    nodeId?: string | null;
    parentCallId?: string | null;
    sendToCallId?: string | null;
    toUserId: string;
    useVideo?: boolean;
    useScreen?: boolean;
    useAudio?: boolean;
    variables?: CallVariables;
}
export declare enum Response {
    STATUS_FAIL = "FAIL",
    STATUS_OK = "OK"
}
export interface Session {
    id: string;
    expire: number;
    user_id: number;
    role_ids: number[];
}
export interface ConnectionInfo {
    sock_id: string;
    server_build_commit: string;
    server_node_id: string;
    server_version: string;
    server_time: number;
    ping_interval?: number;
    session: Session;
}
export interface CallListResponse {
    items?: CallItem[];
    next?: boolean;
}
export interface TaskListResponse {
    items: TaskData[];
}
export interface ConversationListResponse {
    items?: ConversationItem[];
    next?: boolean;
}
export interface StorageFile {
    id: number;
    size: number;
    mime: string;
    name: string;
    shared: string;
}
export declare type FileUploadProgress = (progress: any) => void;
export declare type CallEventHandler = (action: CallActions, call: Call) => void;
export declare type ChatEventHandler = (action: string, conversation: Conversation) => void;
export declare type UsersStatusEventHandler = (state: UserStatus) => void;
export declare type AgentStatusEventHandler = (state: AgentStatusEvent, agent: Agent) => void;
export declare type TaskEventHandler = (action: string, task: Task | undefined) => void;
export declare type QueueJoinMemberHandler = (member: QueueJoinMemberEvent) => void;
export interface ClientEvents {
    disconnected(code: number): void;
    connected(): void;
}
export declare class Client extends EventEmitter<ClientEvents> {
    protected readonly _config: Config;
    agent: Agent;
    phone?: SipPhone;
    private socket;
    private connectionInfo;
    private basePath;
    private reqSeq;
    private queueRequest;
    private log;
    private eventHandler;
    private callStore;
    private conversationStore;
    private pingTimer;
    constructor(_config: Config);
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    subscribeCall(handler: CallEventHandler, data?: object): Promise<CallListResponse>;
    subscribeChat(handler: ChatEventHandler, data?: object): Promise<ConversationListResponse>;
    subscribeUsersStatus(handler: UsersStatusEventHandler, data?: object): Promise<object>;
    subscribeAgentsStatus(handler: AgentStatusEventHandler, data?: object): Promise<object>;
    subscribeTask(handler: TaskEventHandler): void;
    unSubscribe(action: string, handler: CallEventHandler, data?: object): Promise<object>;
    destroy(): Promise<void>;
    allCall(): Call[];
    allConversations(): Conversation[];
    allTask(): Task[];
    callById(id: string): Call | undefined;
    conversationById(id: string): Conversation | undefined;
    callBySipId(id: string): Call | undefined;
    reportingTask(attemptId: number, reporting: Reporting): Promise<object>;
    agentActiveTasks(agentId: number): Promise<object>;
    auth(): Promise<object>;
    ping(): Promise<object>;
    sessionInfo(): Session;
    get version(): string;
    get instanceId(): string;
    agentSession(): Promise<Agent>;
    invite(req: OutboundCallRequest): Promise<object>;
    call(req: OutboundCallRequest): Promise<void>;
    callRecordId(id: string): Promise<object>;
    eavesdrop(req: EavesdropRequest): Promise<object>;
    agentSetOnline(agentId: number, channels: string[], onDemand: boolean): Promise<object>;
    agentSetWaiting(agentId: number, channel: string): Promise<object>;
    agentSetPause(agentId: number, payload?: any): Promise<object>;
    agentSetOffline(agentId: number): Promise<object>;
    inviteToUser(req: UserCallRequest): Promise<object>;
    answer(id: string, req: AnswerRequest): Promise<false | Error | undefined>;
    request(action: string, data?: object): Promise<object>;
    useWebPhone(): boolean;
    callDestroyed(call: Call): boolean;
    conversationDestroyed(conv: Conversation): boolean;
    reportingChannelTask(task: Task): void;
    registerCallClient(phone: SipPhone): Promise<void>;
    deviceConfig(name?: string): Promise<object>;
    storeFile(id: string, files: File[], cb?: FileUploadProgress): Promise<StorageFile[]>;
    fileUrlDownload(fileId: number): string;
    fileUrlStream(fileId: number): string;
    private onMessage;
    private handleAgentStatus;
    private handleChannelEvents;
    private pingServer;
    private connected;
    private callBySession;
    private onNewCallSession;
    private checkAutoAnswer;
    private connectToSocket;
    private handleUserStateEvent;
    private handleCallEvents;
    private handleChatEvents;
    private hasAgentTask;
    private destroyCall;
    private destroyConversation;
}
//# sourceMappingURL=client.d.ts.map