import { CallVariables } from './call';
import { Client, FileUploadProgress } from './client';
import { Reporting, Task, TaskData } from './task';
export declare enum ChatActions {
    Message = "message",
    UserInvite = "user_invite",
    Invite = "invite_conversation",
    Joined = "join_conversation",
    Close = "close_conversation",
    Leave = "leave_conversation",
    Decline = "decline_invite",
    Update = "update_channel",
    Destroy = "destroy"
}
export declare enum ConversationState {
    Init = "init",
    Invite = "invite",
    Active = "active",
    Pending = "pending",
    Closed = "closed"
}
export interface ChatEvent {
    action: string;
    data?: object;
}
export interface BaseChatEvent {
    conversation_id: string;
    timestamp: number;
}
export interface InviteEvent extends BaseChatEvent {
    invite_id: string;
    title: string;
    members: ChatChannel[];
    messages: Message[];
    conversation: ConversationInfo;
    variables?: CallVariables;
}
export interface JoinedEvent extends BaseChatEvent {
    member: ChatChannel;
}
export interface MessageEvent extends BaseChatEvent, Message {
}
export interface LeavedEvent extends BaseChatEvent {
    leaved_channel_id: string;
}
export interface CloseEvent extends BaseChatEvent {
    from_channel_id: string;
    cause: string;
}
export interface DeclineInviteEvent extends BaseChatEvent {
    user_id: number;
    invite_id: string;
}
export interface UpdateChannelEvent extends BaseChatEvent {
    channel_id: string;
    updated_at: number;
}
export interface Message {
    id: number;
    channel_id: string;
    type: string;
    text: string;
    file: MessageFile;
    contact?: object;
    created_at: number;
    updated_at?: number | null;
}
export interface ChatChannel {
    id?: string;
    name?: string;
    type?: string;
    messenger?: string;
    self?: boolean;
}
export interface MessageFile {
    id: number;
    name: string;
    mime: string;
    size: number;
    url: string;
}
export interface MessageWithChannel {
    id: number;
    channelId: string;
    type: string;
    file?: MessageFile;
    text?: string;
    contact?: object | null;
    createdAt: number;
    updatedAt: number;
    member: ChatChannel | null;
}
export interface ConversationInfo {
    id: string;
    title: string;
    created_at: number;
    updated_at: number | null;
}
export interface ConversationItem {
    id: string;
    invite_id?: string;
    channel_id?: string;
    title: string;
    created_at: number;
    closed_at: number;
    updated_at: number;
    joined_at: number;
    leaving_at?: number;
    variables?: CallVariables;
    members: ChatChannel[];
    messages: Message[];
    task?: TaskData;
}
export declare class Conversation {
    private readonly client;
    private readonly conversationId;
    private readonly title;
    data: any;
    state: ConversationState;
    channelId: string | null;
    inviteId: string | null;
    member: ChatChannel;
    members: ChatChannel[];
    _messages: Message[];
    createdAt: number;
    updatedAt: number;
    answeredAt: number;
    invitedAt: number;
    closedAt: number;
    _hasReporting: boolean;
    variables?: CallVariables;
    task: Task | null;
    constructor(client: Client, conversationId: string, title: string, members: ChatChannel[], messages: Message[], variables?: CallVariables);
    setInvite(inviteId: string, timestamp: number): void;
    setAnswered(channelId: string, timestamp: number, member: ChatChannel): void;
    setClosed(timestamp: number): void;
    get id(): string;
    get messages(): MessageWithChannel[];
    getMessages(): MessageWithChannel[];
    next(): Promise<void>;
    pagination(page: number, perPage: number): Promise<void>;
    newMessage(e: MessageEvent): void;
    get allowDecline(): boolean;
    get allowJoin(): boolean;
    get allowLeave(): boolean;
    get allowReporting(): boolean;
    get hasReporting(): boolean;
    get membersId(): string[];
    decline(): Promise<object>;
    join(): Promise<object>;
    close(cause: string): Promise<object>;
    leave(cause: string): Promise<object>;
    sendText(text: string): Promise<object | undefined>;
    sendFile(file: File, cb?: FileUploadProgress): Promise<object>;
    send(data: string | File, cb?: FileUploadProgress): Promise<object | undefined>;
    addToChat(userId: number, title: string): Promise<object>;
    startChat(userId: number): Promise<object>;
    updateChannel(): Promise<object>;
    reporting(reporting: Reporting): Promise<object>;
    renew(sec?: number): Promise<object>;
    private sendMessageTextChunk;
    private messageMember;
}
//# sourceMappingURL=conversation.d.ts.map